General Installation
============

PyPI
~~~~

The latest stable release is available on PyPI, and you can install it by running::

    pip install repytah

Anaconda
~~~~~~~~

If you use Anaconda, you can install the package using ``conda-forge``::

    conda install -c conda-forge repytah

Source
~~~~~~

To build repytah from source, say ``python setup.py build``. Then, to install repytah, say ``python setup.py install``.

Alternatively, you can download or clone the repository and use ``pip`` to handle dependencies::

    unzip repytah.zip
    pip install -e repytah

or::

    git clone https://github.com/smith-tinkerlab/repytah.git
    pip install -e repytah

By calling ``pip list`` you should see ``repytah`` now as an installed package::

    repytah (0.x.x, /path/to/repytah)

